#[non_exhaustive]pub struct RetryConfig { /* private fields */ }Available on crate feature
token-based-authentication only.Expand description
Configuration for handling failed token refresh attempts
Implementations
Sourceimpl RetryConfig
impl RetryConfig
Sourcepub fn set_number_of_retries(self, number_of_retries: usize) -> Self
pub fn set_number_of_retries(self, number_of_retries: usize) -> Self
Sets the maximum number of retry attempts for token refresh
Sourcepub fn set_min_delay(self, min_delay: Duration) -> Self
pub fn set_min_delay(self, min_delay: Duration) -> Self
Sets the minimal delay before attempting to refresh the token after a failure
Sourcepub fn set_max_delay(self, max_delay: Duration) -> Self
pub fn set_max_delay(self, max_delay: Duration) -> Self
Sets the upper bound for retry delays
Sourcepub fn set_exponent_base(self, exponent_base: f32) -> Self
pub fn set_exponent_base(self, exponent_base: f32) -> Self
Sets the base for exponential backoff