[−][src]Enum redis::ConnectionAddr
Defines the connection address.
Not all connection addresses are supported on all platforms. For instance to connect to a unix socket you need to run this on an operating system that supports them.
Variants
Tcp(String, u16)Format for this is (host, port).
Unix(PathBuf)Format for this is the path to the unix socket.
Methods
impl ConnectionAddr[src]
pub fn is_supported(&self) -> bool[src]