SchemaTextField

Struct SchemaTextField 

#[non_exhaustive]
pub struct SchemaTextField { /* private fields */ }
Available on crate feature search_unfinished only.
Represents a text field in the schema.

Implementations

Source

impl SchemaTextField

pub fn new() -> Self

Create a new TEXT field.

pub fn no_stem(self, no_stem: bool) -> Self

Disables stemming when indexing the text field’s values. This may be ideal for things like proper names. https://redis.io/docs/latest/develop/ai/search-and-query/advanced-concepts/stemming/

pub fn weight(self, weight: f64) -> Self

Declares the importance of this attribute when calculating result accuracy. This is a multiplication factor and defaults to 1 if not specified.

pub fn phonetic(self, phonetic: Phonetic) -> Self

Declaring a text attribute as PHONETIC will perform phonetic matching on it in searches by default. https://redis.io/docs/latest/develop/ai/search-and-query/advanced-concepts/phonetic_matching/

pub fn with_suffix_trie(self, with_suffix_trie: bool) -> Self

Keeps a suffix trie with all terms which match the suffix. It is used to optimize contains (foo) and suffix (*foo) queries. Otherwise, a brute-force search on the trie is performed. If suffix trie exists for some fields, these queries will be disabled for other fields.

pub fn index_empty(self, index_empty: bool) -> Self

Index empty strings. This allows searching for empty values - documents that do not contain a specific field. By default, empty strings are not indexed.

pub fn sortable(self, sortable: Sortable) -> Self

Mark the field as sortable.

pub fn no_index(self, no_index: bool) -> Self

Mark the field as no index. This means that the field will not be indexed.

pub fn alias(self, alias: impl Into<String>) -> Self

Set the alias for the field.

pub fn index_missing(self, index_missing: bool) -> Self

Set index missing. This allows searching for missing values - documents that do not contain a specific field.