StreamAddOptions

Struct StreamAddOptions 

pub struct StreamAddOptions { /* private fields */ }
Available on crate feature streams only.
Builder options for xadd_options command

Implementations

Source

impl StreamAddOptions

pub fn nomkstream(self) -> Self

Set the NOMKSTREAM flag on which prevents creating a stream for the XADD operation

pub fn trim(self, trim: StreamTrimStrategy) -> Self

Enable trimming when adding using the given trim strategy

pub fn set_deletion_policy(self, deletion_policy: StreamDeletionPolicy) -> Self

Set the deletion policy for the XADD operation

pub fn idmp( self, producer_id: impl Into<String>, idempotent_id: impl Into<String>, ) -> Self

Enable idempotent message production with manual mode (IDMP)

Manual mode requires both producer ID and idempotent ID to be provided. The producer ID uniquely identifies the message producer. The idempotent ID uniquely identifies this specific message.

Example
use redis::{Commands, streams::StreamAddOptions};

let opts = StreamAddOptions::default()
    .idmp("producer-1", "iid-1");
let _: Option<String> = con.xadd_options(
    "key",
    "*",
    &[("field", "value")],
    &opts
).unwrap();
pub fn idmpauto(self, producer_id: impl Into<String>) -> Self

Enable idempotent message production with automatic mode (IDMPAUTO)

Automatic mode requires only a producer ID to be provided. Redis automatically generates the idempotent ID based on the message content.

Example
use redis::{Commands, streams::StreamAddOptions};

let opts = StreamAddOptions::default()
    .idmpauto("producer-1");
let _: Option<String> = con.xadd_options(
    "key",
    "*",
    &[("field", "value")],
    &opts
).unwrap();