HotkeysResponse

Struct HotkeysResponse 

#[non_exhaustive]
pub struct HotkeysResponse {
Show 16 fields pub tracking_active: bool, pub sample_ratio: u64, pub selected_slots: Vec<SlotRange>, pub all_commands_all_slots_us: u64, pub net_bytes_all_commands_all_slots: u64, pub collection_start_time_unix_ms: u64, pub collection_duration_ms: u64, pub total_cpu_time_user_ms: Option<u64>, pub total_cpu_time_sys_ms: Option<u64>, pub total_net_bytes: Option<u64>, pub by_cpu_time_us: Option<Vec<HotKeyEntry>>, pub by_net_bytes: Option<Vec<HotKeyEntry>>, pub sampled_commands_selected_slots_us: Option<u64>, pub all_commands_selected_slots_us: Option<u64>, pub net_bytes_sampled_commands_selected_slots: Option<u64>, pub net_bytes_all_commands_selected_slots: Option<u64>,
}
Response from the HOTKEYS GET command.

Contains information about the hotkeys tracking session, including tracking metadata, performance statistics, and lists of top K hot keys sorted by the metrics specified in HOTKEYS START.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
tracking_active: bool

Whether tracking is currently active (1) or stopped (0).

sample_ratio: u64

The sampling ratio used during tracking.

selected_slots: Vec<SlotRange>

Array of selected slot ranges.

all_commands_all_slots_us: u64

CPU time in microseconds for all commands on all slots.

net_bytes_all_commands_all_slots: u64

Network bytes for all commands on all slots.

collection_start_time_unix_ms: u64

Unix timestamp in milliseconds when tracking started.

collection_duration_ms: u64

Duration of tracking in milliseconds.

total_cpu_time_user_ms: Option<u64>

User CPU time used in milliseconds (only when CPU metric was specified).

total_cpu_time_sys_ms: Option<u64>

System CPU time used in milliseconds (only when CPU metric was specified).

total_net_bytes: Option<u64>

Total network bytes processed (only when NET metric was specified).

by_cpu_time_us: Option<Vec<HotKeyEntry>>

Array of hotkeys sorted by CPU time in microseconds (only when CPU metric was specified).

by_net_bytes: Option<Vec<HotKeyEntry>>

Array of hotkeys sorted by network bytes (only when NET metric was specified).

sampled_commands_selected_slots_us: Option<u64>

CPU time in microseconds for sampled commands in selected slots (cluster mode with SAMPLE).

all_commands_selected_slots_us: Option<u64>

CPU time in microseconds for all commands in selected slots (cluster mode).

net_bytes_sampled_commands_selected_slots: Option<u64>

Network bytes for sampled commands in selected slots (cluster mode with SAMPLE).

net_bytes_all_commands_selected_slots: Option<u64>

Network bytes for all commands on selected slots (cluster mode).