ErrorKind

Enum ErrorKind 

#[non_exhaustive]
pub enum ErrorKind {
Show 14 variants Parse, AuthenticationFailed, UnexpectedReturnType, InvalidClientConfig, Io, Client, Extension, MasterNameNotFoundBySentinel, NoValidReplicasFoundBySentinel, EmptySentinelList, ClusterConnectionNotFound, Server(ServerErrorKind), Serialize, RESP3NotSupported,
}
An enum of all error kinds.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Parse

The parser failed to parse the server response.



AuthenticationFailed

The authentication with the server failed.



UnexpectedReturnType

Operation failed because of a type mismatch.



InvalidClientConfig

An error that was caused because the parameter to the client were wrong.



Io

This kind is returned if the redis error is one that is not native to the system. This is usually the case if the cause is another error.



Client

An error raised that was identified on the client before execution.



Extension

An extension error. This is an error created by the server that is not directly understood by the library.



MasterNameNotFoundBySentinel

Requested name not found among masters returned by the sentinels



NoValidReplicasFoundBySentinel

No valid replicas found in the sentinels, for a given master name



EmptySentinelList

At least one sentinel connection info is required



ClusterConnectionNotFound

Used when a cluster connection cannot find a connection to a valid node.



Server(ServerErrorKind)

An error returned from the server



Serialize

Available on crate feature json only.

Error Serializing a struct to JSON form



RESP3NotSupported

Redis Servers prior to v6.0.0 doesn’t support RESP3. Try disabling resp3 option