Available on crate feature
vector-sets only.Expand description
Defines types to use with the vector sets commands.
Structs
- VAdd
Options - Options for the VADD command
- VEmb
Options - Options for the VEMB command
- VSim
Options - Options for the VSIM command
Enums
- Embedding
Input - Input data formats that can be used to generate vector embeddings:
- Vector
AddInput - Represents different ways to input data for vector add commands
- Vector
Quantization - Quantization options for vector storage
- Vector
Similarity Search Input - Represents different ways to input query data for vector similarity search commands